@@ -1,11 +1,9 @@
 import argparse
 from typing import Optional, Sequence, Type, TypeVar, Union
 
-from typing_extensions import _GenericAlias  # type: ignore
-
 from . import _construction, _parsers, _strings
 
-DataclassType = TypeVar("DataclassType", bound=Union[Type, _GenericAlias])
+DataclassType = TypeVar("DataclassType")
 
 
 def parse(
@@ -22,7 +20,6 @@ def parse(
     parser_definition, construction_metadata = _parsers.ParserDefinition.from_dataclass(
         cls,
         parent_dataclasses=set(),  # Used for recursive calls.
-        subparser_name_from_type={},  # Aliases for subparsers; this is working, but not yet exposed.
         parent_type_from_typevar=None,  # Used for recursive calls.
         default_instance=None,  # Overrides for default values. This could also be exposed.
     )
